# Copyright 2017-2020 Tobias Leupold <tobias.leupold@gmx.de>
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
# AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
# INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
# LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
# OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
# PERFORMANCE OF THIS SOFTWARE.

if (EXISTS "${BASE_DIR}/.git")
    find_package(Git QUIET)
endif()

set(RSTFILE "${BASE_DIR}/doc/Readme.rst")
set(CSSFILE "${BASE_DIR}/doc/Readme.css")

if (GIT_FOUND)
    execute_process(COMMAND ${GIT_EXECUTABLE} --no-pager log -1 --format=%ad
                            --date=format:%d.%m.%Y -- ${RSTFILE}
                    OUTPUT_VARIABLE LASTCHANGE
                    OUTPUT_STRIP_TRAILING_WHITESPACE)
    include(${CMAKE_CURRENT_LIST_DIR}/GitDescription.cmake)
    git_get_description(VERSION GIT_ARGS)
    message(STATUS "Setting the Readme's last changed date to ${LASTCHANGE}")
    configure_file(${RSTFILE} ${CMAKE_BINARY_DIR}/Readme.rst)
    set(RSTFILE "Readme.rst")
else()
    message(STATUS "Using the released RST Readme")
endif()

message(STATUS "Converting the Readme from RST to HTML")
execute_process(COMMAND ${RST2HTML5} --stylesheet=minimal.css,${CSSFILE}
                        "${RSTFILE}" "share/muckturnier/Readme.htm"
                WORKING_DIRECTORY ${CMAKE_BINARY_DIR})
