/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef ADJUSTDRAWDIALOG_H
#define ADJUSTDRAWDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Draw.h"

// Qt includes
#include <QHash>

// Qt classes
class QTableWidget;

class AdjustDrawDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit AdjustDrawDialog(QWidget *parent,
                              const QVector<QString> &allRegistrations,
                              const QVector<Draw::Seat> &allDraws,
                              bool isPairMode,
                              QString namesSeparator);

public slots:
    void listWasModified();

signals:
    void adoptAdjustment(const QVector<QString> &names, const QVector<Draw::Seat> &seats) const;

private: // Functions
    QVector<int> findIncompletePairs(int pair, QVector<QVector<QString>> &draw) const;
    bool compilePairsSameRole(int pair, QVector<QVector<QString>> &draw);
    bool compilePairsSwitchRole(int pair, QVector<QVector<QString>> &draw);
    QVector<int> findSinglePairs(int pair, QVector<QVector<QString>> &draw) const;
    bool compileOpponentPairs(int pair, QVector<QVector<QString>> &draw);
    bool compileSameTypePairs(int pair, QVector<QVector<QString>> &draw);
    bool fillTableGaps(QVector<QVector<QString>> &draw);

private slots:
    void resizeView();
    void printList();

private: // Variables
    int m_tables;
    QTableWidget *m_changes;
    QHash<QString, Draw::Seat> m_moved;
    QVector<QString> m_names;
    QVector<Draw::Seat> m_newSeats;

};

#endif // ADJUSTDRAWDIALOG_H
