/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "DiscoverClient.h"

#include "network/DiscoverProtocol.h"

// Qt includes
#include <QDebug>
#include <QTimer>

using namespace DiscoverProtocol;

DiscoverClient::DiscoverClient(QObject *parent, int port, int discoverTimeout)
    : AbstractDiscoverEngine(parent, port)
{
    m_timer = new QTimer(this);
    m_timer->setInterval(discoverTimeout);
    m_timer->setSingleShot(true);
    connect(m_timer, &QTimer::timeout, this, &DiscoverClient::discoverTimeout);
}

bool DiscoverClient::discoverServer()
{
    if (! listen()) {
        return false;
    }

    m_timer->start();
    broadcastData(MESSAGE_SEARCHING_SERVER);
    return true;
}

void DiscoverClient::discoverTimeout()
{
    close();
    emit discoverResult(QString(), -1);
}

void DiscoverClient::processData(const QJsonObject &jsonObject, const QHostAddress &)
{
    if (jsonObject.value(KEY_ACTION) != VALUE_ANNOUNCING_SERVER) {
        return;
    }

    m_timer->stop();
    close();
    emit discoverResult(jsonObject.value(KEY_IP).toString(), jsonObject.value(KEY_PORT).toInt());
}
