/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef COMPARERANKINGDIALOG_H
#define COMPARERANKINGDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Database.h"

// Local classes
class SharedObjects;
class TournamentSettings;
class StringTools;

// Qt classes
class QLabel;
class QTableWidget;
class QPushButton;

class CompareRankingDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit CompareRankingDialog(QWidget *parent, SharedObjects *sharedObjects);
    void compareRanking(const QVector<Database::RankData> &remoteRanking);

public slots:
    void clientDisconnected();
    void dataChanged();

signals:
    void rankingRequested() const;

private: // Functions
    void requestRanking();
    void dataReceived();
    const QString differenceString(int local, int remote) const;
    void resizeToTableSize();
    void finishDisplayDifferences();
    bool checkTournamentStarted();

private: // Variables
    Database *m_db;
    TournamentSettings *m_tournamentSettings;
    StringTools *m_stringTools;

    QLabel *m_dataChangedLabel;
    QLabel *m_resultLabel;
    QTableWidget *m_differences;
    QPushButton *m_requestRanking;
    QPushButton *m_close;

};

#endif // COMPARERANKINGDIALOG_H
