/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef COMPARESCOREDIALOG_H
#define COMPARESCOREDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Scores.h"

// Local classes
class SharedObjects;
class Database;
class TournamentSettings;
class StringTools;
class Client;

// Qt classes
class QLabel;
class QTableWidget;
class QPushButton;
class QTableWidget;

class CompareScoreDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit CompareScoreDialog(QWidget *parent, SharedObjects *SharedObjects, Client *client,
                                const int *currentRound);

public slots:
    void clientDisconnected();
    void remoteChecksumChanged(int round);
    void dataChanged();
    void compareScore(Scores::Score &remoteScore);

signals:
    void scoreRequested(int round) const;

private slots:
    void requestScore();

private: // Functions
    void resizeToTableSize();

private: // Variables
    struct Id
    {
        int remote;
        int local;
    };

    Database *m_db;
    TournamentSettings *m_tournamentSettings;
    StringTools *m_stringTools;
    Client *m_client;
    const int *m_currentRound;

    QPushButton *m_request;
    QPushButton *m_close;
    QLabel *m_requesting;
    QLabel *m_differencesLabel;
    QLabel *m_noDifferencesLabel;
    QTableWidget *m_differences;
    QLabel *m_dataChangedLabel;

};

#endif // COMPARESCOREDIALOG_H
