/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef DRAWOVERVIEWPAGE_H
#define DRAWOVERVIEWPAGE_H

// Local includes
#include "shared/OptionalPage.h"
#include "shared/SharedObjects.h"
#include "shared/SearchEngine.h"
#include "shared/Draw.h"

// Local classes
class Settings;
class TournamentSettings;
class SearchWidget;

// Qt classes
class QLabel;
class QTableWidget;

class DrawOverviewPage : public OptionalPage
{
    Q_OBJECT

public:
    explicit DrawOverviewPage(QWidget *parent, SharedObjects *sharedObjects,
                              const QVector<QString> *allRegistrations,
                              const QVector<Draw::Seat> *allDraws,
                              const QVector<int> *incompleteTables,
                              const QVector<int> *tableGaps,
                              bool drawAdjustmentNeeded);
    void updateDraw(bool ownChange, const QString &target, bool deleted);

public slots:
    void resetSearch();
    void drawAdjustmentNeeded(bool state);

signals:
    void showAdjustDrawDialog() const;

public slots:
    bool closePage();

private slots:
    void updateSearch(const QString &searchText);

private: // Functions
    void scrollTo(const QString &target);

private: // Variables
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;
    SearchEngine *m_searchEngine;
    const QVector<QString> *m_allRegistrations;
    const QVector<Draw::Seat> *m_allDraws;
    const QVector<int> *m_incompleteTables;
    const QVector<int> *m_tableGaps;

    QLabel *m_uncompletedTablesLabel;
    QLabel *m_noDraw;

    QLabel *m_isSearch;
    QTableWidget *m_draw;
    QLabel *m_adjustmentLabel;
    SearchWidget *m_searchWidget;

    QVector<QString> m_searchText;

};

#endif // DRAWOVERVIEWPAGE_H
