/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef BASICEXPORTSPAGE_H
#define BASICEXPORTSPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"

// Qt classes
class QCheckBox;
class QLineEdit;
class QRadioButton;

class BasicExportPage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    enum FileFormat {
        HTML,
        CSV
    };

    explicit BasicExportPage(const QString &title, QWidget *parent = nullptr);
    virtual void saveSettings() override;

    bool exportTitle() const;
    QString title() const;

    FileFormat fileFormat() const;

    bool openAfterExport() const;
    bool closeAfterExport() const;

signals:
    void closeAfterExportToggled(bool state);

private slots:
    void checkTitle(const QString &text);

private: // Variables
    QCheckBox *m_exportTitle;
    QLineEdit *m_title;

    QRadioButton *m_exportHTML;
    QRadioButton *m_exportCSV;

    QCheckBox *m_openAfterExport;
    QCheckBox *m_closeAfterExport;

};

#endif // BASICEXPORTSPAGE_H
