/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef EXPORTDATASETSPAGE_H
#define EXPORTDATASETSPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"

// Qt includes
#include <QSet>
#include <QList>
#include <QPalette>

// Qt classes
class QCheckBox;
class QLabel;
class QLineEdit;

class ExportDatasetsPage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit ExportDatasetsPage(int rounds, QWidget *parent = nullptr);
    virtual void saveSettings() override;

    bool exportGenericData() const;
    bool exportRanking() const;

    bool exportRoundResults() const;
    QList<int> roundSelection() const;

signals:
    void checkExportPossible() const;

private slots:
    void checkRoundSelection(const QString &range);

private: // Functions
    void roundSelectionIsInvalid(const QString &message = QString());

private: // Variables
    const int m_allRounds;
    QPalette m_defaultPalette;
    QPalette m_redTextPalette;

    QCheckBox *m_exportGenericData;

    QCheckBox *m_exportRanking;

    QString m_allRoundsString;
    QCheckBox *m_exportRoundResults;
    QLineEdit *m_roundSelect;
    QLabel *m_roundSelectLabel;
    QLabel *m_errorLabel;
    bool m_roundSelectionIsRed = false;
    QSet<int> m_selectedRounds;

};

#endif // EXPORTDATASETSPAGE_H
