/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "ExportFormattingPage.h"

// Qt includes
#include <QVBoxLayout>
#include <QCheckBox>
#include <QGroupBox>
#include <QRadioButton>

ExportFormattingPage::ExportFormattingPage(const QString &boogerSymbol, QWidget *parent)
    : AbstractSettingsPage(tr("Formatierung"), parent)
{
    auto *headlinesBox = new QGroupBox(tr("Überschriften"));
    auto *headlinesLayout = new QVBoxLayout(headlinesBox);
    layout()->addWidget(headlinesBox);

    m_exportHeadlines = new QCheckBox(tr("Überschriften anzeigen "
                                         "(z.\u2009B. „Einzelergebnisse“)"));
    m_exportHeadlines->setChecked(true);
    headlinesLayout->addWidget(m_exportHeadlines);

    m_exportSubHeadlines = new QCheckBox(tr("Unterüberschriften anzeigen "
                                            "(z.\u2009B. „Spielergebnisse der 1. Runde“)"));
    m_exportSubHeadlines->setChecked(true);
    headlinesLayout->addWidget(m_exportSubHeadlines);

    auto *boogersBox = new QGroupBox(tr("Bobbl"));
    auto *boogersLayout = new QVBoxLayout(boogersBox);
    layout()->addWidget(boogersBox);

    m_displayBoogers = new QCheckBox(tr("Bobbl („%1“) anzeigen").arg(boogerSymbol));
    m_displayBoogers->setChecked(true);
    boogersLayout->addWidget(m_displayBoogers);

    auto *goalsBox = new QGroupBox(tr("Nicht entscheidende Tore"));
    auto *goalsLayout = new QVBoxLayout(goalsBox);
    layout()->addWidget(goalsBox);

    m_displayUnimportantGoals = new QRadioButton(tr("Anzeigen"));
    m_displayUnimportantGoals->setChecked(true);
    goalsLayout->addWidget(m_displayUnimportantGoals);

    m_braceUnimportantGoals = new QRadioButton(tr("Einklammern"));
    goalsLayout->addWidget(m_braceUnimportantGoals);

    m_hideUnimportantGoals = new QRadioButton(tr("Ausblenden"));
    goalsLayout->addWidget(m_hideUnimportantGoals);

    layout()->addStretch();
}

void ExportFormattingPage::saveSettings()
{
}

bool ExportFormattingPage::exportHeadlines() const
{
    return m_exportHeadlines->isChecked();
}

bool ExportFormattingPage::exportSubHeadlines() const
{
    return m_exportSubHeadlines->isChecked();
}

bool ExportFormattingPage::displayBoogers() const
{
    return m_displayBoogers->isChecked();
}

ExportFormattingPage::UnimportantGoalsHandling ExportFormattingPage::unimportantGoalsHandling() const
{
    if (m_displayUnimportantGoals->isChecked()) {
        return UnimportantGoalsHandling::Display;
    } else if (m_braceUnimportantGoals->isChecked()) {
        return UnimportantGoalsHandling::Brace;
    } else { // m_hideUnimportantGoals->isChecked()
        return UnimportantGoalsHandling::Hide;
    }
}
