/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef EXPORTTOURNAMENTDIALOG_H
#define EXPORTTOURNAMENTDIALOG_H

// Local includes
#include "shared/FileDialog.h"
#include "shared/Database.h"

// Qt classes
class QTextStream;

// Local classes
class SharedObjects;
class StringTools;
class TournamentSettings;
class BasicExportPage;
class ExportDatasetsPage;
class ExportFormattingPage;

class ExportTournamentDialog : public FileDialog
{
    Q_OBJECT

public:
    explicit ExportTournamentDialog(QWidget *parent, SharedObjects *SharedObjects);

private: // Functions
    struct GoalsData
    {
        QString goals;
        QString opponentGoals;
    };

    void saveHtmlFile(QTextStream &outStream);
    void saveHtmlHorizontalRoundResults(QTextStream &outStream);
    void saveHtmlVerticalRoundResults(QTextStream &outStream);
    void saveCsvFile(QTextStream &outStream);
    void saveCsvHorizontalRoundResults(QTextStream &outStream);
    void saveCsvVerticalRoundResults(QTextStream &outStream);

    QVector<GoalsData> prepareGoals(const QVector<Database::RankData> &ranking) const;
    QString displayScore(int score) const;

private slots:
    virtual void accept() override;
    void checkExportPossible();

private: // Variables
    Database *m_db;
    StringTools *m_stringTools;
    TournamentSettings *m_tournamentSettings;
    const QString m_dateFormat;
    const QString m_timeFormat;

    BasicExportPage *m_basicExportPage;
    ExportDatasetsPage *m_exportDatasetsPage;
    ExportFormattingPage *m_exportFormattingPage;

};

#endif // EXPORTTOURNAMENTDIALOG_H
