/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "DrawSettingsPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"
#include "shared/DrawSettingsWidget.h"

// Qt includes
#include <QVBoxLayout>
#include <QLabel>

DrawSettingsPage::DrawSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                                   TournamentSettings *tournamentSettings,
                                   QWidget *parent)
    : AbstractSettingsPage(tr("Auslosung"), parent),
      m_tournamentSettings(tournamentSettings)
{
    QLabel *drawSettingsLabel = new QLabel(tr(
        "Die hier einstellbaren Optionen können auf der „Anmeldung“-Seite (via „Einstellungen“ → "
        "„Einstellungen für die Auslosung“) beliebig verändert werden, auch während des "
        "Turniers."));
    drawSettingsLabel->setWordWrap(true);
    layout()->addWidget(drawSettingsLabel);

    m_drawSettingsWidget = new DrawSettingsWidget;
    m_drawSettingsWidget->updateSettings(tournamentTemplate.drawSettings);
    layout()->addWidget(m_drawSettingsWidget);

    auto *drawOverviewLabel = new QLabel(tr("Für die „Übersicht Auslosung“-Seite siehe "
                                            "<a href=\"#raiseOptionalPages\">Optionale "
                                            "Seiten</a>!"));
    drawOverviewLabel->setWordWrap(true);
    drawOverviewLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
    connect(drawOverviewLabel, &QLabel::linkActivated, this, &DrawSettingsPage::linkActivated);
    layout()->addWidget(drawOverviewLabel);

    layout()->addStretch();
}

void DrawSettingsPage::saveSettings()
{
    m_tournamentSettings->setDrawSettings(m_drawSettingsWidget->settings());
}
