/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "OptionalPagesPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"
#include "shared/OptionalPages.h"

// Qt includes
#include <QLabel>
#include <QVBoxLayout>
#include <QCheckBox>
#include <QDebug>

OptionalPagesPage::OptionalPagesPage(const TournamentTemplate::Settings &tournamentTemplate,
                                     TournamentSettings *tournamentSettings,
                                     QWidget *parent)
    : AbstractSettingsPage(tr("Optionale Seiten"), parent),
      m_tournamentSettings(tournamentSettings)
{
    auto *inputSettingsLabel = new QLabel(tr("Folgende optional anzeigbare Seiten können bereits "
                                             "beim Starten eingeblendet werden:"));
    inputSettingsLabel->setWordWrap(true);
    layout()->addWidget(inputSettingsLabel);

    m_drawOverviewPage = new QCheckBox(tr("Übersicht Auslosung (einblendbar über „Extras“)"));
    m_drawOverviewPage->setChecked(
        tournamentTemplate.optionalPages.contains(OptionalPages::Page::DrawOverview));
    connect(m_drawOverviewPage, &QCheckBox::toggled,
            this, &OptionalPagesPage::drawOverviewPageSelected);
    layout()->addWidget(m_drawOverviewPage);

    layout()->addStretch();
}

void OptionalPagesPage::saveSettings()
{
    m_tournamentSettings->setOptionalPageShown(OptionalPages::Page::DrawOverview,
                                               m_drawOverviewPage->isChecked());
}

void OptionalPagesPage::showDrawOverviewPage()
{
    m_drawOverviewPage->setChecked(true);
}
