/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "RankingSettingsPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"

// Qt includes
#include <QLabel>
#include <QVBoxLayout>
#include <QGroupBox>
#include <QCheckBox>

RankingSettingsPage::RankingSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                                         TournamentSettings *tournamentSettings,
                                         QWidget *parent)
    : AbstractSettingsPage(tr("Rangliste"), parent),
      m_tournamentSettings(tournamentSettings)
{
    QLabel *rankingSettingsLabel = new QLabel(tr("Die hier einstellbaren Optionen können auf der "
                                                 "„Rangliste“-Seite beliebig verändert werden, "
                                                 "auch während des Turniers."));
    rankingSettingsLabel->setWordWrap(true);
    layout()->addWidget(rankingSettingsLabel);

    QGroupBox *rankingCreationBox = new QGroupBox(tr("Ranglistenerstellung"));
    QVBoxLayout *rankingCreationLayout = new QVBoxLayout(rankingCreationBox);
    layout()->addWidget(rankingCreationBox);

    m_includeOpponentGoals = new QCheckBox(tr("Gegnerische geschossene Tore berücksichtigen"));
    m_includeOpponentGoals->setChecked(tournamentTemplate.includeOpponentGoals);
    rankingCreationLayout->addWidget(m_includeOpponentGoals);

    QGroupBox *rankingDisplayBox = new QGroupBox(tr("Ranglistendarstellung"));
    QVBoxLayout *rankingDisplayLayout = new QVBoxLayout(rankingDisplayBox);
    layout()->addWidget(rankingDisplayBox);

    m_grayOutUnimportantGoals = new QCheckBox(tr("Nicht entscheidende Tore ausgrauen"));
    m_grayOutUnimportantGoals->setChecked(tournamentTemplate.includeOpponentGoals);
    rankingDisplayLayout->addWidget(m_grayOutUnimportantGoals);

    layout()->addStretch();
}

void RankingSettingsPage::saveSettings()
{
    m_tournamentSettings->setIncludeOpponentGoals(m_includeOpponentGoals->isChecked());
    m_tournamentSettings->setGrayOutUnimportantGoals(m_grayOutUnimportantGoals->isChecked());
}
