/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "ScoreSettingsPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"

// Qt includes
#include <QLabel>
#include <QVBoxLayout>
#include <QGroupBox>
#include <QGridLayout>
#include <QRadioButton>
#include <QCheckBox>
#include <QDebug>

ScoreSettingsPage::ScoreSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                                     TournamentSettings *tournamentSettings,
                                     QWidget *parent)
    : AbstractSettingsPage(tr("Ergebniseingabe"), parent),
      m_tournamentSettings(tournamentSettings)
{
    QLabel *inputSettingsLabel = new QLabel(tr("Die hier einstellbaren Optionen können auf der "
                                               "„Ergebnisse“-Seite beliebig verändert werden, auch "
                                               "während des Turniers."));
    inputSettingsLabel->setWordWrap(true);
    layout()->addWidget(inputSettingsLabel);

    // Score type

    QGroupBox *scoreTypeBox = new QGroupBox(tr("Spielstandzettel"));
    QGridLayout *scoreTypeLayout = new QGridLayout(scoreTypeBox);
    layout()->addWidget(scoreTypeBox);

    m_scoreTypeHorizontal = new QRadioButton(tr("Horizontal"));
    m_scoreTypeHorizontal->setChecked(
        tournamentTemplate.scoreType == Tournament::ScoreType::Horizontal);
    scoreTypeLayout->addWidget(m_scoreTypeHorizontal, 0, 0, Qt::AlignTop);

    scoreTypeLayout->addWidget(descriptionLabel(tr("Die Paare stehen oben und unten, die Bobbl "
                                                   "werden von links nach rechts aufgeschrieben")),
                               0, 1);

    m_scoreTypeVertical = new QRadioButton(tr("Vertikal"));
    m_scoreTypeVertical->setChecked(
        tournamentTemplate.scoreType != Tournament::ScoreType::Horizontal);
    scoreTypeLayout->addWidget(m_scoreTypeVertical, 1, 0, Qt::AlignTop);

    scoreTypeLayout->addWidget(descriptionLabel(tr("Die Paare stehen links und rechts, die Bobbl "
                                                   "werden von oben nach unten aufgeschrieben")),
                               1, 1);

    // Automatic pairs selection

    m_autoSelectBox = new QGroupBox(tr("Automatische Paarauswahl"));
    QVBoxLayout *autoSelectBoxLayout = new QVBoxLayout(m_autoSelectBox);
    m_autoSelectBox->setEnabled(! tournamentTemplate.noTableNumbers);
    layout()->addWidget(m_autoSelectBox);

    m_autoSelectPairs = new QCheckBox(tr("Automatische Auswahl laut Auslosung"));
    m_autoSelectPairs->setChecked(tournamentTemplate.autoSelectPairs);
    autoSelectBoxLayout->addWidget(m_autoSelectPairs);

    m_selectByLastRound = new QCheckBox(tr("Paar 2 rückt pro Runde weiter"));
    m_selectByLastRound->setChecked(tournamentTemplate.selectByLastRound);
    m_lastSelectByLastRoundState = tournamentTemplate.selectByLastRound;
    autoSelectBoxLayout->addWidget(m_selectByLastRound);

    // Table numbers

    QGroupBox *tableNumbersBox = new QGroupBox(tr("Tischnummern"));
    QVBoxLayout *tableNumbersBoxLayout = new QVBoxLayout(tableNumbersBox);
    layout()->addWidget(tableNumbersBox);

    m_noTableNumbers = new QCheckBox(tr("Eingabe ohne Tischnummern"));
    m_noTableNumbers->setChecked(tournamentTemplate.noTableNumbers);
    connect(m_noTableNumbers, &QCheckBox::stateChanged,
            this, &ScoreSettingsPage::noTableNumbersChanged);
    tableNumbersBoxLayout->addWidget(m_noTableNumbers);

    layout()->addStretch();
}

void ScoreSettingsPage::singlePlayersModeSelected(bool state)
{
    if (state) {
        m_lastSelectByLastRoundState = m_selectByLastRound->isChecked();
        m_selectByLastRound->setChecked(false);
    } else {
        m_selectByLastRound->setChecked(m_lastSelectByLastRoundState);
    }
}

void ScoreSettingsPage::noTableNumbersChanged(int state)
{
    if (state) {
        m_lastAutoSelectPairsState = m_autoSelectPairs->isChecked();
        m_lastSelectByLastRoundState = m_selectByLastRound->isChecked();
        m_autoSelectPairs->setChecked(false);
        m_selectByLastRound->setChecked(false);
    } else {
        m_autoSelectPairs->setChecked(m_lastAutoSelectPairsState);
        m_selectByLastRound->setChecked(m_lastSelectByLastRoundState);
    }
    m_autoSelectBox->setEnabled(! state);
}

void ScoreSettingsPage::saveSettings()
{
    m_tournamentSettings->setScoreType(m_scoreTypeHorizontal->isChecked()
                                           ? Tournament::ScoreType::Horizontal
                                           : Tournament::ScoreType::Vertical);
    m_tournamentSettings->setAutoSelectPairs(m_autoSelectPairs->isChecked());
    m_tournamentSettings->setSelectByLastRound(m_selectByLastRound->isChecked());
    m_tournamentSettings->setNoTableNumbers(m_noTableNumbers->isChecked());
}
