/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SCORESETTINGSPAGE_H
#define SCORESETTINGSPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"

// Local classes

class TournamentSettings;

namespace TournamentTemplate
{
struct Settings;
}

// Qt classes
class QRadioButton;
class QCheckBox;
class QGroupBox;

class ScoreSettingsPage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit ScoreSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                               TournamentSettings *tournamentSettings,
                               QWidget *parent = nullptr);
    virtual void saveSettings() override;

public slots:
    void singlePlayersModeSelected(bool state);

private slots:
    void noTableNumbersChanged(int state);

private: // Variables
    TournamentSettings *m_tournamentSettings;
    QRadioButton *m_scoreTypeHorizontal;
    QRadioButton *m_scoreTypeVertical;
    QGroupBox *m_autoSelectBox;
    QCheckBox *m_autoSelectPairs;
    QCheckBox *m_selectByLastRound;
    QCheckBox *m_noTableNumbers;

    bool m_lastAutoSelectPairsState;
    bool m_lastSelectByLastRoundState;

};

#endif // SCORESETTINGSPAGE_H
