/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef RANKINGPAGE_H
#define RANKINGPAGE_H

// Local includes
#include "shared/Database.h"

// Qt includes
#include <QWidget>
#include <QMap>

// Qt classes
class QGroupBox;
class QLabel;
class QTableWidget;
class QAction;
class QComboBox;

// Local classes
class SharedObjects;
class SearchEngine;
class SearchWidget;
class TournamentSettings;

class RankingPage : public QWidget
{
    Q_OBJECT

public:
    explicit RankingPage(QWidget *parent, SharedObjects *sharedObjects);
    void setupGui();
    void reload(int upToRound = 0);

signals:
    void statusUpdate(const QString &message);
    void scoreChanged();
    void enableExport(bool state);

public slots:
    void dataChanged();
    void resetSearch();

private slots:
    void updateSearch(const QString &searchText);
    void includeOpponentGoalsChanged();
    void grayOutUnimportantGoalsChanged();

private: // Functions
    void grayOutUnimportantGoals(const QVector<Database::RankData> &ranking);
    QColor grayedOutColor(const QColor &color);

private: // Variables
    Database *m_db;
    SearchEngine *m_searchEngine;
    TournamentSettings *m_tournamentSettings;

    QAction *m_includeOpponentGoals;
    QAction *m_grayOutUnimportantGoals;

    QGroupBox *m_settingsBox;
    QGroupBox *m_rankingBox;
    QLabel *m_interimLabel;
    QLabel *m_noResultsLabel;
    QTableWidget *m_ranking;
    SearchWidget *m_searchWidget;
    QLabel *m_isSearchLabel;
    QComboBox *m_upToRound;
    QLabel *m_upToRoundLabel;
    QLabel *m_multipleRanks;

    // This is the cache for the grayed out colors.
    // We can't use a QColor as a QHash key, therefore, it's QRgb/uint representation is used
    QHash<QRgb, QColor> m_grayedOutColors;

};

#endif // RANKINGPAGE_H
