/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef DRAWPOPUP_H
#define DRAWPOPUP_H

// Local includes
#include "shared/SelectionPopup.h"
#include "shared/Draw.h"

// Qt classes
class QSpinBox;
class QRadioButton;
class QLabel;
class QPushButton;

class DrawPopup : public SelectionPopup
{
    Q_OBJECT

public:
    explicit DrawPopup(QWidget *parent, const Draw::Settings *drawSettings);
    void show(Draw::Seat seat, bool empty, bool allRoundsFinished, bool isSinglePlayer,
              const QPoint &position);
    void setAssignedTables(QVector<int> &assignedPair1Tables, QVector<int> &assignedPair2Tables);
    Draw::Seat seat() const;
    void setPairMode(bool state);
    QVector<Draw::Seat> completeDraw(int seats) const;

private slots:
    void checkSelection();
    void selectFirstFreeSeat();
    void drawSeat();
    void confirmDelete();

private: // Functions
    int findFirstGap(const QVector<int> &list) const;
    void selectSeat(const Draw::Seat &seat);
    bool isSeatTaken(const Draw::Seat &seat) const;
    Draw::Seat getRandomSeat() const;

private: // Variables
    const Draw::Settings *m_drawSettings;

    QVector<int> m_assignedPair1Tables;
    QVector<int> m_assignedPair2Tables;
    int m_assignmentsPerPair;
    Draw::Seat m_firstFreeSeat;
    QVector<Draw::Seat> m_drawableSeats;
    bool m_drawingPossible = false;
    bool m_allRoundsFinished;

    QWidget *m_main;
    QWidget *m_selection;
    QLabel *m_isSinglePlayer;
    QSpinBox *m_table;
    QRadioButton *m_pair1;
    QRadioButton *m_pair2;
    QLabel *m_taken;
    QLabel *m_beyondLimit;
    QPushButton *m_save;
    QPushButton *m_delete;
    QPushButton *m_newDraw;

};

#endif // DRAWPOPUP_H
