/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "DrawSettingsDialog.h"

#include "shared/DrawSettingsWidget.h"

// Qt includes
#include <QVBoxLayout>
#include <QDebug>

DrawSettingsDialog::DrawSettingsDialog(QWidget *parent) : TitleDialog(parent, DeleteMode::NoDelete)
{
    setTitle(tr("Einstellungen für die Auslosung"));
    addButtonBox(QDialogButtonBox::Save | QDialogButtonBox::Close | QDialogButtonBox::Reset);
    buttonBox()->button(QDialogButtonBox::Save)->setText(tr("Speichern und schließen"));

    connect(buttonBox()->button(QDialogButtonBox::Reset), &QPushButton::clicked,
            this, &DrawSettingsDialog::resetValues);

    m_drawSettingsWidget = new DrawSettingsWidget;
    layout()->addWidget(m_drawSettingsWidget);
}

void DrawSettingsDialog::updateSettings(const Draw::Settings &settings)
{
    m_drawSettingsWidget->updateSettings(settings);
    m_initialSettings = settings;
}

Draw::Settings DrawSettingsDialog::settings() const
{
    return m_drawSettingsWidget->settings();
}

void DrawSettingsDialog::resetValues()
{
    m_drawSettingsWidget->updateSettings(m_initialSettings);
}
