/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef MARKERDIALOG_H
#define MARKERDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Markers.h"

// Qt classes
class QLineEdit;
class QComboBox;
class QLabel;
class QTableWidget;

class MarkerDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit MarkerDialog(QWidget *parent, const QColor &background, QTableWidget *markers);
    void setName(const QString &text);
    void setSorting(Markers::MarkerSorting sorting);
    void disableSortingSelection();
    void setEditedName(const QString &name);
    void setIsEditing();
    bool isEditing() const;

signals:
    void markerSaved(const QString &name, const QColor &color, Markers::MarkerSorting sorting);

public slots:
    void setColor(const QColor &color);

private slots:
    void chooseColor();
    virtual void accept() override;

private: // Functions
    qreal contrastRatio(const QColor &color1, const QColor &color2) const;
    qreal relativeLuminance(const QColor &color) const;
    qreal prepareColorComponent(qreal component) const;

private: // Variables
    const QColor m_background;
    QTableWidget *m_markers;
    QLineEdit *m_name;
    QLabel *m_badContrast;
    QComboBox *m_sorting;
    QString m_editedName;
    bool m_isEditing = false;

};

#endif // MARKERDIALOG_H
