/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "RegistrationDelegate.h"
#include "PlayersEditor.h"

// Qt includes
#include <QLineEdit>
#include <QDebug>

RegistrationDelegate::RegistrationDelegate(QObject *parent) : TableDelegate(parent)
{
    connect(this, &QAbstractItemDelegate::closeEditor, [this] { m_isEditing = false; } );
}

QString RegistrationDelegate::editedText() const
{
    return m_isEditing ? m_originalData : QString();
}

QString RegistrationDelegate::enteredText() const
{
    return m_isEditing ? m_editor->text() : QString();
}

bool RegistrationDelegate::isEditing() const
{
    return m_isEditing;
}

void RegistrationDelegate::saveEditorState()
{
    m_enteredText = m_editor->text();

    if (m_editor->hasSelectedText()) {
        if (m_editor->cursorPosition() == m_editor->selectionStart()) {
            m_selectionStart = m_editor->selectionStart() + m_editor->selectedText().length();
            m_selectionLength = m_editor->selectedText().length() * -1;
        } else {
            m_selectionStart = m_editor->selectionStart();
            m_selectionLength = m_editor->selectedText().length();
        }
    } else {
        m_selectionStart = -1;
        m_cursorPosition = m_editor->cursorPosition();
    }

    abortEdit();
}

void RegistrationDelegate::abortEdit()
{
    m_editor->setText(m_originalData);
    m_editor->clearFocus();
}

void RegistrationDelegate::restoreEditorState()
{
    m_editor->setText(m_enteredText);
    if (m_selectionStart != -1) {
        m_editor->setSelection(m_selectionStart, m_selectionLength);
    } else {
        m_editor->setCursorPosition(m_cursorPosition);
    }
}

QWidget *RegistrationDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &,
                                            const QModelIndex &index) const
{
    emit startedEdit(index.row());
    m_isEditing = true;
    m_originalData = index.data().toString();
    m_editor = new PlayersEditor(m_originalData, parent);
    return m_editor;
}

void RegistrationDelegate::setModelData(QWidget *, QAbstractItemModel *, const QModelIndex &) const
{
    if (! m_editor->enterPressed()) {
        // The editing has been finished because the editor lost it's focus
        return;
    }

    const QString enteredData = enteredText().simplified();
    if (enteredData.isEmpty() || enteredData == m_originalData) {
        return;
    }

    emit editEntered(m_originalData, enteredData);
}
