/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef REGISTRATIONDELEGATE_H
#define REGISTRATIONDELEGATE_H

// Local includes
#include "shared/TableDelegate.h"

// Local classes
class PlayersEditor;

class RegistrationDelegate : public TableDelegate
{
    Q_OBJECT

public:
    explicit RegistrationDelegate(QObject *parent);
    bool isEditing() const;
    QString editedText() const;
    QString enteredText() const;
    void saveEditorState();
    void restoreEditorState();
    void abortEdit();

protected:
    virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &,
                                  const QModelIndex &index) const override;
    virtual void setModelData(QWidget *, QAbstractItemModel *, const QModelIndex &) const override;

signals:
    void startedEdit(int row) const;
    void editEntered(const QString &originalData, const QString &enteredData) const;

private:
    mutable bool m_isEditing = false;
    mutable PlayersEditor *m_editor;
    mutable QString m_originalData;
    QString m_enteredText;
    int m_cursorPosition;
    int m_selectionStart;
    int m_selectionLength;

};

#endif // REGISTRATIONDELEGATE_H
