/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef RESTOREBACKUPDIALOG_H
#define RESTOREBACKUPDIALOG_H

// Local includes
#include "shared/TitleDialog.h"

// Qt includes
#include <QDateTime>

// Local classes
class Database;
class BackupEngine;

// Qt classes
class QListWidget;

class RestoreBackupDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit RestoreBackupDialog(QWidget *parent, Database *db, BackupEngine &backupEngine,
                                 const QString &dbToOverwrite, bool autoAccept);

signals:
    void statusUpdate(const QString &text);
    void closeTournament();
    void openTournament(const QString &dbFile);

protected slots:
    virtual void accept() override;

private slots:
    void runAutoAccept();

private: // Functions
    QString formatDateString(const QString &backupDate) const;

private: // Variables
    Database *m_db;
    QListWidget *m_backups;
    QString m_dbToOverwrite;
    bool m_autoAccept;

};

#endif // RESTOREBACKUPDIALOG_H
