/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "BoogerRadioButton.h"
#include "BoogerSpinBox.h"

// Qt includes
#include <QDebug>
#include <QApplication>
#include <QWheelEvent>

BoogerRadioButton::BoogerRadioButton(QWidget *parent, BoogerSpinBox *spinBox)
    : QRadioButton(parent), m_spinBox(spinBox)
{
    setContextMenuPolicy(Qt::PreventContextMenu);
}

void BoogerRadioButton::wheelEvent(QWheelEvent *event)
{
    QRadioButton::wheelEvent(event);
    if (isChecked()) {
        QApplication::sendEvent(m_spinBox, event);
    }
}

void BoogerRadioButton::mousePressEvent(QMouseEvent *event)
{
    if (event->button() == Qt::RightButton) {
        // Simulate a left mouse click so that the GUI responses accordingly
        QMouseEvent leftEvent(QEvent::MouseButtonPress, event->localPos(),
                              Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
        QRadioButton::mousePressEvent(&leftEvent);
    } else {
        QRadioButton::mousePressEvent(event);
    }
}

void BoogerRadioButton::mouseReleaseEvent(QMouseEvent *event)
{
    if (event->button() == Qt::RightButton) {
        if (! isChecked()) {
            setChecked(true);
            emit clicked();
        } else {
            m_spinBox->setFocus();
            m_spinBox->selectAll();
        }
        emit scorePopupRequested(m_spinBox);
    }

    QRadioButton::mouseReleaseEvent(event);
}
