/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef BOOGERWIDGET_H
#define BOOGERWIDGET_H

// Local includes
#include "shared/Tournament.h"

// Qt includes
#include <QWidget>
#include <QPushButton>

// Qt Classes
class QPushButton;

// Local classes
class BoogerSpinBox;
class BoogerRadioButton;

class BoogerWidget : public QWidget
{
    Q_OBJECT

public:
    explicit BoogerWidget(QWidget *parent, Tournament::ScoreType scoreType,
                          int booger, int boogersPerRound, int boogerScore);
    int score(int pair) const;
    void setScore(int pair1Score, int pair2Score);
    void setAsFirstAborted();
    void setAborted(bool aborted);
    void reset();
    bool isAborted() const;

signals:
    void returnPressed();
    void abortedStateChanged(int booger, bool aborted);
    void scorePopupRequested(BoogerSpinBox *spinBox);

private slots:
    void toggleScore();
    void abortedButtonClicked(bool aborted);

private: // Variables
    const int m_boogerScore;
    const int m_boogerNumber;
    QVector<BoogerSpinBox *> m_score;
    QVector<BoogerRadioButton *> m_booger;
    QPushButton *m_boogerAborted;

};

#endif // BOOGERWIDGET_H
