/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef PLAYERSCOMBOBOX_H
#define PLAYERSCOMBOBOX_H

// Local includes
#include "NumbersComboBox.h"

// Local classes
class SearchEngine;
class PlayersLineEdit;

// Qt classes
class QStringListModel;

class PlayersComboBox : public NumbersComboBox
{
    Q_OBJECT

public:
    explicit PlayersComboBox(SearchEngine *searchEngine, int index, QWidget *parent = nullptr);

signals:
    void disableSaveScore();
    void checkSavePossible();
    void selectionChanged(int pair, int pairId);

public slots:
    void lineEditTextChanged(const QString &text);
    void setPhoneticSearch(bool state);

private slots:
    void resetLineEditText();
    void completerActivated(const QString &text);
    void processGivenText();
    void popupHidden();
    void finishSearch();

private: // Variables
    SearchEngine *m_searchEngine;
    const int m_index;
    PlayersLineEdit *m_lineEdit;
    QStringListModel *m_matches;
    bool m_isSearching;
    bool m_completerActivated;
    bool m_phoneticSearch = false;

};

#endif // PLAYERSCOMBOBOX_H
