/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "ScoreWidget.h"
#include "BoogerWidget.h"

#include "shared/SharedStyles.h"

// Qt includes
#include <QPushButton>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QGridLayout>
#include <QLabel>
#include <QDebug>

ScoreWidget::ScoreWidget(Tournament::ScoreType scoreType,
                         const QVector<BoogerWidget *> &boogerWidgets,
                         QPushButton *saveScore, QWidget *parent)
    : MinimumViewportWidget(parent)
{
    setStyleSheet(QStringLiteral("ScoreWidget { background-color: transparent; }"));

    switch (scoreType) {

    case Tournament::ScoreType::Horizontal:
    {
        QHBoxLayout *layout = new QHBoxLayout(this);
        layout->setContentsMargins(0, 0, 0, 0);

        for (BoogerWidget *boogerWidget : boogerWidgets) {
            layout->addWidget(boogerWidget);
        }

        layout->addWidget(saveScore);

        setMinimumViewport(sizeHint());

    }
    break;

    case Tournament::ScoreType::Vertical:
    {
        QHBoxLayout *layout = new QHBoxLayout(this);
        layout->setContentsMargins(0, 0, 0, 0);

        QGridLayout *boogerLayout = new QGridLayout;
        layout->addLayout(boogerLayout);
        int i = 0;
        for (BoogerWidget *boogerWidget : boogerWidgets) {
            QLabel *boogerHeader = new QLabel(tr("%1. Bobbl").arg(++i));
            boogerHeader->setStyleSheet(SharedStyles::BOLD_TEXT);
            boogerLayout->addWidget(boogerHeader, i - 1, 0);
            boogerLayout->addWidget(boogerWidget, i - 1, 1);
        }

        QVBoxLayout *saveLayout = new QVBoxLayout;
        saveLayout->setAlignment(Qt::AlignBottom);
        layout->addLayout(saveLayout);
        saveLayout->addWidget(saveScore);

        const int count = boogerWidgets.count();
        const QSize hint = sizeHint();
        setMinimumViewport(QSize(hint.width(), hint.height() / count * (count == 1 ? 1 : 2)));

    }
    break;

    }
}
