/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "TableLineEdit.h"

// Qt includes
#include <QKeyEvent>
#include <QFocusEvent>
#include <QTimer>
#include <QDebug>

TableLineEdit::TableLineEdit(QWidget *parent)
    : StyledLineEdit(parent), m_noItemText(tr("–"))
{
}

const QString &TableLineEdit::noItemText() const
{
    return m_noItemText;
}

void TableLineEdit::keyPressEvent(QKeyEvent *event)
{
    const int key = event->key();

    // Disallow leading zeros and negative numbers
    if ((cursorPosition() == 0 || selectionStart() == 0)
        && (key == Qt::Key_0 || key == Qt::Key_Minus)) {

        return;
    }

    QLineEdit::keyPressEvent(event);
}

void TableLineEdit::focusInEvent(QFocusEvent *event)
{
    QLineEdit::focusInEvent(event);
    if (event->reason() == Qt::MouseFocusReason || event->reason() == Qt::TabFocusReason) {
        if (text() == m_noItemText) {
            clear();
        } else {
            QTimer::singleShot(0, this, &QLineEdit::selectAll);
        }
    }
}

void TableLineEdit::focusOutEvent(QFocusEvent *event)
{
    QLineEdit::focusOutEvent(event);
    if (text().isEmpty()) {
        setText(m_noItemText);
        setStyleSheet(QString());
    }
}
