/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "Connection.h"

#include "network/ServerProtocol.h"

// Qt includes
#include <QDebug>
#include <QTcpSocket>
#include <QJsonDocument>
#include <QJsonObject>
#include <QDataStream>

using namespace ServerProtocol;

Connection::Connection(QObject *parent) : AbstractNetworkEngine(parent)
{
    connect(socket(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error),
            this, &Connection::error);
    connect(socket(), &QAbstractSocket::disconnected, this, &Connection::disconnected);
}

bool Connection::setSocketDescriptor(qintptr descriptor)
{
    return socket()->setSocketDescriptor(descriptor);
}

void Connection::close()
{
    socket()->abort();
    emit disconnected();
}

void Connection::dataReceived(const QString &action, const QJsonObject &jsonObject)
{
    if (action == ACTION_HANDSHAKE) {
        processHandshake(jsonObject);
    } else {
        emit clientRequest(action, jsonObject);
    }
}

void Connection::processHandshake(const QJsonObject &jsonObject)
{
    const QJsonValue phaseValue = jsonObject.value(HANDSHAKE_KEY_PHASE);
    if (phaseValue.type() != QJsonValue::String) {
        emit handshakeResult(HANDSHAKE_PHASE_FAILED);
        close();
        return;
    }
    emit handshakeResult(phaseValue.toString());
}

void Connection::setId(int id)
{
    m_id = id;
}

int Connection::id() const
{
    return m_id;
}
