/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SERVERPAGE_H
#define SERVERPAGE_H

// Local includes
#include "shared/OptionalPage.h"

// Local classes
class SharedObjects;
class RegistrationPage;
class Server;
class SocketAddressWidget;
class LogDisplay;
class DiscoverServer;

// Qt classes
class QLabel;
class QPushButton;
class QGroupBox;

class ServerPage : public OptionalPage
{
    Q_OBJECT

public:
    explicit ServerPage(QWidget *parent, SharedObjects *sharedObjects,
                        RegistrationPage *registrationPage,
                        const QMap<int, QString> *scoreChecksums);
    bool checkServerRunning();
    Server *server() const;

public slots:
    bool closePage();

signals:
    void serverStarted();
    void serverStopped();
    void statusUpdate(const QString &text);

private slots:
    void startServer();
    bool stopServer();
    void updateClientCount(int count);

private: // Variables
    Server *m_server;
    SocketAddressWidget *m_socketAddress;
    QGroupBox *m_settingsBox;
    QPushButton *m_startServer;
    QPushButton *m_stopServer;
    QPushButton *m_closeButton;
    QLabel *m_address;
    QGroupBox *m_displayBox;
    LogDisplay *m_display;
    QString m_serverStoppedMessage;
    DiscoverServer *m_discoverServer;

};

#endif // SERVERPAGE_H
