/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef MARKERSTEMPLATEPAGE_H
#define MARKERSTEMPLATEPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"
#include "shared/Markers.h"

// Local classes
class SharedObjects;
class Database;
class Settings;
class TournamentSettings;

// Qt classes
class QTableWidget;
class QGroupBox;
class QLabel;
class QTableWidgetItem;

class MarkersTemplatePage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit MarkersTemplatePage(SharedObjects *sharedObjects, QWidget *parent = nullptr);
    virtual void saveSettings() override;

private slots:
    void restoreTemplate();
    void adoptCurrentSettings();

private: // Functions
    void updateTemplateDisplay();
    const Markers::Marker &findMarker(int id) const;
    QString markerName(int id) const;
    QTableWidgetItem *markerItem(int id) const;

private: // Enums
    enum SettingsRow {
        Default,
        Drawn,
        Absent,
        Count
    };

private: // Variables
    Database *m_db;
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;

    QVector<Markers::Marker> m_markersTemplate;
    Markers::SinglesManagement m_singlesManagementTemplate;
    int m_defaultMarker;
    int m_drawnMarker;
    int m_absentMarker;

    QTableWidget *m_markersTemplateDisplay;
    QTableWidget *m_settingsDisplay;

    QLabel *m_noProcessSingles;
    QGroupBox *m_processSingles;
    QLabel *m_singlesMarker;
    QLabel *m_automaticMarking;
    QLabel *m_assignedMarker;

};

#endif // MARKERSTEMPLATEPAGE_H
