/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "SettingsDialog.h"
#include "FileNameTemplatePage.h"
#include "TournamentTemplatePage.h"
#include "MarkersTemplatePage.h"
#include "StringsPage.h"
#include "SaveOnClosePage.h"
#include "NetworkPage.h"

#include "shared/SharedObjects.h"
#include "shared/StackedWidgetList.h"
#include "shared/AbstractSettingsPage.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QListWidget>
#include <QStackedWidget>

SettingsDialog::SettingsDialog(QWidget *parent, SharedObjects *sharedObjects, bool networkInUse)
    : TitleDialog(parent)
{
    setTitle(tr("Einstellungen"));
    addButtonBox(QDialogButtonBox::Save | QDialogButtonBox::Close);
    buttonBox()->button(QDialogButtonBox::Save)->setText(tr("Speichern und schließen"));

    m_list = new StackedWidgetList;
    layout()->addWidget(m_list);

    const QVector<AbstractSettingsPage *> pages {
        new FileNameTemplatePage(sharedObjects->settings()),
        new TournamentTemplatePage(sharedObjects),
        new MarkersTemplatePage(sharedObjects),
        new StringsPage(sharedObjects->settings(), networkInUse),
        new SaveOnClosePage(sharedObjects->settings()),
        new NetworkPage(sharedObjects->settings())
    };

    for (AbstractSettingsPage *page : pages) {
        m_list->addWidget(page);
    }

    m_list->setCurrentIndex(0);
}

void SettingsDialog::accept()
{
    for (int i = 0; i < m_list->count(); i++) {
        qobject_cast<AbstractSettingsPage *>(m_list->widget(i))->saveSettings();
    }
    TitleDialog::accept();
}
