/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef TOURNAMENTTEMPPLATEPAGE_H
#define TOURNAMENTTEMPPLATEPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"
#include "shared/Settings.h"
#include "shared/TournamentTemplate.h"

// Local classes
class SharedObjects;
class Database;
class TournamentSettings;

// Qt classes
class QTableWidget;
class QTableWidgetItem;

class TournamentTemplatePage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit TournamentTemplatePage(SharedObjects *sharedObjects, QWidget *parent = nullptr);
    virtual void saveSettings() override;

public slots:
    void adoptCurrentSettings();

private slots:
    void restoreTemplate();

private: // Enums
    enum Row {
        TournamentMode,
        BoogerScore,
        BoogersPerRound,
        DrawSettings,
        RegistrationColumns,
        RegistrationListHeaderHidden,
        ScoreType,
        AutoSelectPairs,
        SelectByLastRound,
        NoTableNumbers,
        IncludeOpponentGoals,
        GrayOutUnimportantGoals,
        OptionalPages,
        Count
    };

private: // Functions
    QTableWidgetItem *itemFor(Row row) const;
    QString boolText(bool state) const;
    void updateTemplateDisplay();

private: // Variables
    Database *m_db;
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;
    TournamentTemplate::Settings m_template;
    QTableWidget *m_templateDisplay;
    int m_styleAddition;

};

#endif // TOURNAMENTTEMPPLATEPAGE_H
