/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "ExpandingLabel.h"

// Qt includes
#include <QDebug>

ExpandingLabel::ExpandingLabel(QWidget *parent) : QLabel(parent)
{
    setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
    setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
    setMinimumHeight(15);
}

void ExpandingLabel::resizeText()
{
    QString text = this->text();
    if (text.isEmpty()) {
        return;
    }

    QRect labelSpace = contentsRect();
    QFont font = this->font();

    int size = 0;
    const auto steps = { 100, 50, 25, 10, 5, 1 };
    for (int step : steps) {
        while (true) {
            size += step;
            font.setPointSize(size);
            QFontMetrics fontMetrics(font);
            QRect targetSpace = fontMetrics.boundingRect(text);

            if (targetSpace.height() > labelSpace.height()
                || targetSpace.width() > labelSpace.width()) {

                size -= step;
                break;
            }
        }
    }

    setFont(font);
}

void ExpandingLabel::resizeEvent(QResizeEvent *event)
{
    QLabel::resizeEvent(event);
    resizeText();
}
