/* Copyright (c) 2017-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef STOPWATCH_H
#define STOPWATCH_H

// Local includes
#include "shared/TitleDialog.h"

// Qt includes
#include <QDateTime>

// Local classes
class Settings;
class TimeLabel;
class ExpandingLabel;

// Qt classes
class QTimer;
class QSpinBox;
class QPushButton;
class QCheckBox;
class QLineEdit;

class StopWatchDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit StopWatchDialog(QWidget *parent, Settings *settings);
    bool isRunning() const;

protected: // Functions
    virtual void closeEvent(QCloseEvent *event) override;

private slots:
    void update();
    void start();
    void stop();
    void pause();

private: // Functions
    void setTarget(qint64 seconds);
    void toggleTitleInput(bool checked);

private: // Variables
    Settings *m_settings;
    QTimer *m_timer;
    TimeLabel *m_timeDisplay;
    QWidget *m_settingsWidget;
    QWidget *m_controlWidget;
    QSpinBox *m_hours;
    QSpinBox *m_minutes;
    QSpinBox *m_seconds;
    QPushButton *m_pause;
    QDateTime m_targetTime;
    ExpandingLabel *m_title;
    QCheckBox *m_displayTitle;
    QLineEdit *m_titleInput;
    bool m_isRunning;
    QByteArray m_geometry;

};

#endif // STOPWATCH_H
