/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "AbstractJsonEngine.h"

// Qt includes
#include <QJsonDocument>

AbstractJsonEngine::AbstractJsonEngine(QObject *parent) : QObject(parent)
{
}

QByteArray AbstractJsonEngine::jsonObjectToByteArray(const QJsonObject &jsonObject) const
{
    return QJsonDocument(jsonObject).toJson(QJsonDocument::Compact);
}

TSuccess<QJsonObject> AbstractJsonEngine::jsonObjectFromByteArray(const QByteArray &byteArray) const
{
    QJsonParseError error;
    const QJsonDocument json = QJsonDocument::fromJson(byteArray, &error);
    if (error.error != QJsonParseError::NoError || ! json.isObject()) {
        return { QJsonObject(), false };
    }
    return { json.object(), true };
}
