/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef ABSTRACTNETWORKENGINE_H
#define ABSTRACTNETWORKENGINE_H

// Local includes
#include "AbstractJsonEngine.h"

// Qt classes
class QJsonObject;
class QTcpSocket;

class AbstractNetworkEngine : public AbstractJsonEngine
{
    Q_OBJECT

signals:
    void protocolError(const QString &text);

public:
    static QString colorToString(const QColor &color);
    static QColor colorFromValue(const QJsonValue &value);

    void sendData(const QJsonObject &jsonObject);
    QString ip() const;

protected:
    explicit AbstractNetworkEngine(QObject *parent);

protected slots:
    void readData();

protected: // Functions
    QTcpSocket *socket() const;
    virtual void dataReceived(const QString &action, const QJsonObject &jsonObject) = 0;

private: // Variables
    QTcpSocket *m_socket;

};

#endif // ABSTRACTNETWORKENGINE_H
