/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "Led.h"

// Qt includes
#include <QTimer>
#include <QFontMetrics>
#include <QDebug>

// C++ includes
#include <functional>

namespace
{
const QString CSS = QStringLiteral("border: 1 solid rgb(160, 160, 160); "
                                   "border-radius: %1; "
                                   "background-color: %2;");
}

Led::Led(int size, QWidget *parent) : QLabel(parent)
{
    // Make the size even
    size = size * 2 / 2;

    const QString borderRadius = QString::number(size / 2);

    m_css = { { Led::State::Off,
                CSS.arg(borderRadius, QStringLiteral("rgb(220, 220, 220)")) },
              { Led::State::Red,
                CSS.arg(borderRadius, QStringLiteral("rgb(230, 10, 10)")) },
              { Led::State::Green,
                CSS.arg(borderRadius, QStringLiteral("rgb(10, 230, 10)")) } };

    setFixedSize(size, size);
    setState(State::Off);

    m_flashTimer = new QTimer(this);
    m_flashTimer->setInterval(250);
    m_flashTimer->setSingleShot(true);
    connect(m_flashTimer, &QTimer::timeout, this, std::bind(&Led::setState, this, State::Off));
}

void Led::setState(State state)
{
    setStyleSheet(m_css.value(state));
}

void Led::flash()
{
    setStyleSheet(m_css.value(State::Green));
    m_flashTimer->start();
}
