/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes

#include "NetworkStatusWidget.h"
#include "Led.h"

#include "shared/IconSizeEngine.h"

// Qt includes
#include <QHBoxLayout>
#include <QLabel>

NetworkStatusWidget::NetworkStatusWidget(IconSizeEngine *iconSizeEngine, QWidget *parent)
    : QWidget(parent)
{
    auto *layout = new QHBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 3);

    const int size = iconSizeEngine->relativeWidth(0.55);

    m_connectionLed = new Led(size);
    layout->addWidget(m_connectionLed);
    m_connectionLabel = new QLabel;
    layout->addWidget(m_connectionLabel);

    const QString txHelp = tr("Blinkt auf, wenn Daten gesendet werden");
    m_txLed = new Led(size);
    m_txLed->setWhatsThis(txHelp);
    layout->addWidget(m_txLed);
    auto *txLabel = new QLabel(tr("Tx"));
    txLabel->setWhatsThis(txHelp);
    layout->addWidget(txLabel);

    const QString rxHelp = tr("Blinkt auf, wenn Daten empfangen werden");
    m_rxLed = new Led(size);
    m_rxLed->setWhatsThis(rxHelp);
    layout->addWidget(m_rxLed);
    auto *rxLabel = new QLabel(tr("Rx"));
    rxLabel->setWhatsThis(rxHelp);
    layout->addWidget(rxLabel);
}

void NetworkStatusWidget::setMode(Mode mode)
{
    switch (mode) {
    case Mode::Server:
        m_connectionLabel->setText(tr("Server gestoppt"));
        break;
    case Mode::Client:
        m_connectionLabel->setText(tr("Verbunden"));
        break;
    }

    m_connectionLed->setState(Led::Red);
}

void NetworkStatusWidget::clientCountChanged(int count)
{
    m_connectionLabel->setText(tr("%n Client(s) angemeldet", "", count));
    m_connectionLed->setState(count != 0 ? Led::Green : Led::Off);
}

void NetworkStatusWidget::setConnected(bool state)
{
    m_connectionLed->setState(state ? Led::Green : Led::Red);
}

void NetworkStatusWidget::tx()
{
    m_txLed->flash();
}

void NetworkStatusWidget::rx()
{
    m_rxLed->flash();
}
