/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SOCKETADDRESSWIDGET_H
#define SOCKETADDRESSWIDGET_H

// Qt includes
#include <QWidget>
#include <QHostAddress>

// Qt classes
class QComboBox;
class QLineEdit;

class SocketAddressWidget : public QWidget
{
    Q_OBJECT

public:
    enum Mode {
        Server,
        Client
    };

    explicit SocketAddressWidget(Mode mode, int defaultPort, bool preferIpv6,
                                 QWidget *parent = nullptr);
    QString ip() const;
    int port() const;
    void setSocketAddress(const QString &ip, int port);
    void focusIp();

signals:
    void settingsOkay(bool state);
    void returnPressed();

private slots:
    void checkSettings();

private: // Variables
    QComboBox *m_ip;
    QLineEdit *m_port;
    QHostAddress m_hostAddress;

};

#endif // SOCKETADDRESSWIDGET_H
