/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "AbstractSettingsPage.h"

// Qt includes
#include <QVBoxLayout>
#include <QGroupBox>
#include <QLabel>

AbstractSettingsPage::AbstractSettingsPage(const QString &pageTitle, QWidget *parent)
    : QWidget(parent), m_pageTitle(pageTitle)
{
    QVBoxLayout *mainLayout = new QVBoxLayout(this);
    mainLayout->setContentsMargins(0, 0, 0, 0);
    QGroupBox *groupBox = new QGroupBox(m_pageTitle);
    m_layout = new QVBoxLayout(groupBox);
    mainLayout->addWidget(groupBox);
}

QString AbstractSettingsPage::pageTitle() const
{
    return m_pageTitle;
}

QVBoxLayout *AbstractSettingsPage::layout() const
{
    return m_layout;
}

QLabel *AbstractSettingsPage::descriptionLabel(const QString &text) const
{
    QLabel *label = new QLabel(text);
    label->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
    label->setAlignment(Qt::AlignTop);
    label->setWordWrap(true);
    return label;
}
