/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "ChecksumHelper.h"

// Qt includes
#include <QCryptographicHash>

namespace
{
const QChar SPACE = QLatin1Char(' ');
}

ChecksumHelper::ChecksumHelper(QObject *parent) : QObject(parent)
{
}

void ChecksumHelper::addData(const QString &data)
{
    m_data.append(data);
    m_data.append(SPACE);
}

void ChecksumHelper::addData(int data)
{
    m_data.append(QString::number(data));
    m_data.append(SPACE);
}

void ChecksumHelper::addData(const Draw::Seat &seat)
{
    m_data.append(QString::number(seat.table));
    m_data.append(SPACE);
    m_data.append(QString::number(seat.pair));
    m_data.append(SPACE);
}

QString ChecksumHelper::checksum() const
{
    QCryptographicHash hash(QCryptographicHash::Md5);
    hash.addData(m_data.toUtf8());
    return QLatin1String(hash.result().toHex());
}
