/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "DefeatableMessageBox.h"

// Qt includes
#include <QCheckBox>

DefeatableMessageBox::DefeatableMessageBox(QObject *parent) : QObject(parent)
{
}

bool DefeatableMessageBox::dontAsk(const char *id) const
{
    return m_dontAsk[id];
}

void DefeatableMessageBox::setDontAsk(const char *id, bool state)
{
    m_dontAsk[id] = state;
}

QMessageBox::StandardButton DefeatableMessageBox::show(const char *id, QWidget *parent,
                                                       const QString &title, const QString &text,
                                                       QMessageBox::StandardButton defaultButton)
{
    QCheckBox *dontAsk = new QCheckBox(tr("Nicht mehr nachfragen"));
    dontAsk->setChecked(true);
    QMessageBox messageBox(parent);
    messageBox.setIcon(QMessageBox::Question);
    messageBox.setWindowTitle(title);
    messageBox.setText(text);
    messageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
    messageBox.setDefaultButton(defaultButton);
    messageBox.setCheckBox(dontAsk);

    const auto result = static_cast<QMessageBox::StandardButton>(messageBox.exec());
    m_dontAsk[id] = dontAsk->isChecked();

    return result;
}
