/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef DRAW_H
#define DRAW_H

namespace Draw
{

constexpr int SETTINGS_VERSION = 1;

struct Settings
{
    bool consecutive;
    int tablesLimit;
    int randomDraw;
    int windowDraw;
    int consecutiveDraw;
};

const Settings DEFAULT_SETTINGS {
    false, // consecutive
    -1,    // tablesLimit
    -1,    // randomDraw
    4,     // windowDraw
    -1     // consecutiveDraw
};

struct Seat
{
    int table = 0;
    int pair = 0;

    bool isEmpty() const
    {
        return this->table == 0;
    }

    bool operator ==(const Seat &other) const
    {
        return this->table == other.table && this->pair == other.pair;
    }

    bool operator !=(const Seat &other) const
    {
        return this->table != other.table || this->pair != other.pair;
    }
};

const Seat EMPTY_SEAT { 0, 0 };

int indexForPair(int pair);
int indexForPlayer(int pair, int player);
int otherPair(int pair);
int pairForIndex(int index);
int playerForIndex(int index);

}

#endif // DRAW_H
