/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "DrawMapper.h"

// Qt includes
#include <QHash>

// C++ includes
#include <algorithm>

namespace DrawMapper
{

QVector<QVector<QString>> mapDraw(const QVector<QString> &allRegistrations,
                                  const QVector<Draw::Seat> &allDraws)
{
    QHash<int, QVector<QString>> draw;
    for (int i = 0; i < allRegistrations.count(); i++) {
        const auto &seat = allDraws.at(i);
        if (! draw.contains(seat.table)) {
            auto players = QVector<QString>(4);
            players[Draw::indexForPair(seat.pair)] = allRegistrations.at(i);
            draw.insert(seat.table, players);
        } else {
            int index = Draw::indexForPair(seat.pair);
            if (! draw.value(seat.table).at(index).isEmpty()) {
                index++;
            }
            draw[seat.table][index] = allRegistrations.at(i);
        }
    }

    QVector<QVector<QString>> sortedDraw;
    const auto tables = draw.keys();
    for (int i = 1; i <= *std::max_element(tables.begin(), tables.end()); i++) {
        if (draw.contains(i)) {
            sortedDraw.append(draw.value(i));
        } else {
            sortedDraw.append(QVector<QString>(4));
        }
    }

    return sortedDraw;
}

}
