/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef DRAWSETTINGSWIDGET_H
#define DRAWSETTINGSWIDGET_H

// Local includes
#include "Draw.h"

// Qt includes
#include <QWidget>

// Qt classes
class QRadioButton;
class QSpinBox;
class QLabel;
class QCheckBox;

class DrawSettingsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit DrawSettingsWidget(QWidget *parent = nullptr);
    void updateSettings(const Draw::Settings &settings);
    Draw::Settings settings() const;

private slots:
    void optionStateChanged(bool state, QSpinBox *target);

private: // Functions
    void adjustLimits();

private: // Variables
    QRadioButton *m_consecutive;
    QRadioButton *m_random;
    QCheckBox *m_tablesLimitSet;
    QSpinBox *m_tablesLimit;
    QCheckBox *m_randomDrawSet;
    QSpinBox *m_randomDraw;
    QCheckBox *m_windowDrawSet;
    QSpinBox *m_windowDraw;
    QCheckBox *m_consecutiveDrawSet;
    QSpinBox *m_consecutiveDraw;
    bool m_adjusting = false;
    bool m_updatingSettings = false;

};

#endif // DRAWSETTINGSWIDGET_H
