/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "IconSizeEngine.h"

// Qt includes
#include <QWidget>
#include <QFont>
#include <QFontMetrics>
#include <QDebug>

// C++ includes
#include <cmath>

IconSizeEngine::IconSizeEngine(QObject *parent) : QObject(parent)
{
    // The following calculation should set m_MHeight to 20(px) if the default
    // font size and family is used. We use os-dependant factors to achieve this.

    QWidget widget;
    const auto metrics = QFontMetrics(widget.font());
    m_MHeight = metrics.boundingRect(QStringLiteral("M")).height()
#ifdef Q_OS_LINUX
                    * 1.17647;
#endif
#ifdef Q_OS_WIN
                    * 1.54836;
#endif
#ifdef Q_OS_MACOS
                    * 1.33333;
#endif

    // If the user's desktop defines another font size, the icons should be scaled accordingly.
}

QSize IconSizeEngine::relativeSize(double factor) const
{
    const int size = relativeWidth(factor);
    return QSize(size, size);
}

int IconSizeEngine::relativeWidth(double factor) const
{
    return int(std::round(m_MHeight * factor));
}
