/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef JSONHELPER_H
#define JSONHELPER_H

// Local includes
#include "Markers.h"
#include "RegistrationColumns.h"
#include "Draw.h"
#include "OptionalPages.h"

// Qt classes
class QJsonObject;
class QJsonArray;
class QString;

namespace JsonHelper
{

QString serializeJson(const QJsonObject &json);
QString serializeJson(const QJsonArray &json);
QJsonObject jsonObjectFromString(const QString &data);
QJsonArray jsonArrayFromString(const QString &data);

QString singlesManagementToString(const Markers::SinglesManagement &data);
QJsonObject singlesManagementToJson(const Markers::SinglesManagement &data);
Markers::SinglesManagement parseSinglesManagement(const QString &data);
Markers::SinglesManagement parseSinglesManagement(const QJsonObject &jsonObject);

QString registrationColumnsToString(const QVector<RegistrationColumns::Column> &columns);
QJsonArray registrationColumnsToJson(const QVector<RegistrationColumns::Column> &columns);
QVector<RegistrationColumns::Column> parseRegistrationColumns(const QString &data);
QVector<RegistrationColumns::Column> parseRegistrationColumns(const QJsonArray &jsonArray);

QString drawSettingsToString(const Draw::Settings &settings);
QJsonObject drawSettingsToJson(const Draw::Settings &settings);
Draw::Settings parseDrawSettings(const QString &data);
Draw::Settings parseDrawSettings(const QJsonObject &jsonObject);

QString optionalPagesToString(const QVector<OptionalPages::Page> &pages);
QJsonArray optionalPagesToJson(const QVector<OptionalPages::Page> &pages);
QVector<OptionalPages::Page> parseOptionalPages(const QString &data);
QVector<OptionalPages::Page> parseOptionalPages(const QJsonArray &json);

// Legacy functions needed for updates
QVector<RegistrationColumns::Column> parsePlayersPageColumns(const QString &data);
QVector<RegistrationColumns::Column> parsePlayersPageColumns(const QJsonObject &jsonObject);

}

#endif // JSONHELPER_H
