/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "MinimumViewportScroll.h"
#include "MinimumViewportWidget.h"

// Qt includes
#include <QResizeEvent>
#include <QDebug>
#include <QScrollBar>

MinimumViewportScroll::MinimumViewportScroll(Qt::Orientation orientation, QWidget *parent)
    : QScrollArea(parent),
      m_orientation(orientation)
{
}

void MinimumViewportScroll::resizeEvent(QResizeEvent *event)
{
    QScrollArea::resizeEvent(event);

    if (widget() == nullptr) {
        return;
    }

    switch (m_orientation) {
    case Qt::Horizontal:
        setMinimumWidth(qobject_cast<MinimumViewportWidget *>(widget())->minimumViewport().width()
                        + (verticalScrollBar()->isVisible() ? verticalScrollBar()->width()
                                                            : 0));
        break;
    case Qt::Vertical:
        setMinimumHeight(qobject_cast<MinimumViewportWidget *>(widget())->minimumViewport().height()
                        + (horizontalScrollBar()->isVisible() ? horizontalScrollBar()->height()
                                                              : 0));
        break;
    }
}
