/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "PhoneticSearchButton.h"
#include "SharedObjects.h"
#include "ResourceFinder.h"
#include "Settings.h"

// Qt includes
#include <QTimer>
#include <QDebug>

PhoneticSearchButton::PhoneticSearchButton(const QString &searchId, SharedObjects *sharedObjects,
                                           const QString &header, QWidget *parent)
    : IconButton(sharedObjects, QStringLiteral("phonetic.png"), parent)
{
    setObjectName(searchId);
    setToolTip(header.isEmpty() ? tr("<p>Phonetische Suche (de)aktivieren</p>") : header);
    setWhatsThis(toolTip()
                 + tr("<p>Die phonetische Suche sucht nicht nach der eingegebenen Buchstabenfolge "
                      "oder Variantionen davon, sondern nach deren Klang beim Sprechen.</p>"
                      "<p>Sie ist viel Tippfehler-toleranter, liefert aber auch mehr falsche "
                      "Ergebnisse.</p>"));

    Settings *settings = sharedObjects->settings();

    connect(this, &QAbstractButton::toggled, this, [this, settings]
    {
        settings->savePhoneticSearchState(objectName(), isChecked());
    });

    // We do this via a QTimer call so that slots connected to the toggled signal will be handled
    QTimer::singleShot(0, this, [this, settings]
    {
        setChecked(settings->phoneticSearchState(objectName()));
    });
}
