/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SEARCHENGINE_H
#define SEARCHENGINE_H

// Qt includes
#include <QObject>
#include <QHash>
#include <QVector>

// Local classes
class StringTools;

class SearchEngine : public QObject
{
    Q_OBJECT

public:
    enum SearchType {
        Default,
        DrawnPairsScore,
        DrawnPairsDraw
    };

    explicit SearchEngine(QObject *parent, StringTools *stringTools);
    bool checkMatch(const QString &text, SearchType searchType, bool phoneticSearch) const;
    void clearSearchCache(SearchType searchType = SearchType::Default);
    void updateSearchCache(const QString &name, SearchType searchType = SearchType::Default);
    void setSearchTerm(const QString &text);
    QHash<QString, QStringList> checkListForPossibleDuplicates(const QStringList &list,
                                                               bool phoneticSearch);

private: // Functions
    QVector<QString> searchVariants(const QString &text);
    QString stripDiacritis(const QString &text) const;
    bool checkMatch(const QVector<QString> &variantList, bool phoneticSearch) const;
    QString removeSequentialCharacters(QString text) const;
    QString koelnerPhonetik(const QString &text) const;
    void setSearchTerm(const QVector<QString> &variantsList);

private: // Variables
    StringTools *m_stringTools;
    const QHash<SearchType, QHash<QString, QVector<QString>> *> m_variantsCache;
    QHash<QString, QVector<QString>> m_defaultVariants;
    QHash<QString, QVector<QString>> m_drawnPairsScoreVariants;
    QHash<QString, QVector<QString>> m_drawnPairsDrawVariants;
    QVector<QHash<QString, int>> m_searchTerm;

};

#endif // SEARCHENGINE_H
