/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SEARCHWIDGET_H
#define SEARCHWIDGET_H

// Qt includes
#include <QWidget>

// Local classes;
class SharedObjects;
class SearchLineEdit;
class PhoneticSearchButton;

// Qt classes
class QLabel;

class SearchWidget : public QWidget
{
    Q_OBJECT

public:
    explicit SearchWidget(const QString &searchId, SharedObjects *sharedObjects,
                          QWidget *parent = nullptr);
    void updateMatches(int matches, int hiddenMatches = 0);
    void saveSearch();
    void restoreSearch();
    bool phoneticSearch() const;
    QString searchText() const;

public slots:
    void clear();

signals:
    void searchChanged(const QString &text);

private slots:
    void processInput(const QString &text);

private: // Variables
    QLabel *m_searchLabel;
    SearchLineEdit *m_search;
    QLabel *m_matches;
    QString m_savedSearch;
    PhoneticSearchButton *m_phoneticSearch;

};

#endif // SEARCHWIDGET_H
