/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef SHAREDOBJECTS_H
#define SHAREDOBJECTS_H

// Qt includes
#include <QObject>

// Local classes
class StringTools;
class SearchEngine;
class Database;
class ResourceFinder;
class Settings;
class TournamentSettings;
class DefeatableMessageBox;
class IconSizeEngine;

class SharedObjects : public QObject
{
    Q_OBJECT

public:
    explicit SharedObjects(QObject *parent = nullptr);
    StringTools *stringTools() const;
    SearchEngine *searchEngine() const;
    ResourceFinder *resourceFinder() const;
    Database *database() const;
    Settings *settings() const;
    TournamentSettings *tournamentSettings() const;
    DefeatableMessageBox *defeatableMessageBox() const;
    IconSizeEngine *iconSizeEngine() const;

private: // Variables
    StringTools *m_stringTools;
    SearchEngine *m_searchEngine;
    Database *m_database;
    ResourceFinder *m_resourceFinder;
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;
    DefeatableMessageBox *m_defeatableMessageBox;
    IconSizeEngine *m_iconSizeEngine;

};

#endif // SHAREDOBJECTS_H
