/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "StackedWidgetList.h"
#include "AbstractSettingsPage.h"

// Qt includes
#include <QDebug>
#include <QHBoxLayout>
#include <QListWidget>
#include <QStackedWidget>

StackedWidgetList::StackedWidgetList(QWidget *parent) : QWidget(parent)
{
    QHBoxLayout *layout = new QHBoxLayout(this);
    layout->setContentsMargins(0, 0, 0, 0);

    m_widgetsList = new QListWidget;
    connect(m_widgetsList, &QListWidget::currentItemChanged,
            this, &StackedWidgetList::changeWidget);
    layout->addWidget(m_widgetsList);

    m_widgetsStack = new QStackedWidget;
    layout->addWidget(m_widgetsStack);
}

void StackedWidgetList::addWidget(QWidget *widget, const QString &title)
{
    m_widgetsList->addItem(title);
    m_widgetsStack->addWidget(widget);

    const int width = m_widgetsList->sizeHintForColumn(0) + 4;
    m_widgetsList->setMinimumWidth(width);
    m_widgetsList->setMaximumWidth(width);
}

void StackedWidgetList::addWidget(AbstractSettingsPage *page)
{
    addWidget(page, page->pageTitle());
}

void StackedWidgetList::setCurrentIndex(int index)
{
    m_widgetsList->setCurrentRow(index);
    m_widgetsList->setFocus();
}

void StackedWidgetList::setCurrentWidget(QWidget *widget)
{
    m_widgetsList->setCurrentRow(m_widgetsStack->indexOf(widget));
    m_widgetsList->setFocus();
}

int StackedWidgetList::count() const
{
    return m_widgetsStack->count();
}

QWidget *StackedWidgetList::widget(int index) const
{
    return m_widgetsStack->widget(index);
}

void StackedWidgetList::changeWidget(QListWidgetItem *item, QListWidgetItem *)
{
    m_widgetsStack->setCurrentIndex(m_widgetsList->row(item));
}

void StackedWidgetList::setNavigationVisible(bool state)
{
    m_widgetsList->setVisible(state);
}

int StackedWidgetList::currentIndex() const
{
    return m_widgetsStack->currentIndex();
}
