/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef STACKEDWIDGETLIST_H
#define STACKEDWIDGETLIST_H

// Qt includes
#include <QWidget>

// Local classes
#include "AbstractSettingsPage.h"

// Qt classes
class QListWidget;
class QStackedWidget;
class QListWidgetItem;

class StackedWidgetList : public QWidget
{
    Q_OBJECT

public:
    explicit StackedWidgetList(QWidget *parent = nullptr);
    void addWidget(QWidget *widget, const QString &title);
    void addWidget(AbstractSettingsPage *page);
    void setCurrentIndex(int index);
    void setCurrentWidget(QWidget *widget);
    int count() const;
    QWidget *widget(int index) const;
    void setNavigationVisible(bool state);
    int currentIndex() const;

private slots:
    void changeWidget(QListWidgetItem *item, QListWidgetItem *);

private: // Variables
    QListWidget *m_widgetsList;
    QStackedWidget *m_widgetsStack;

};

#endif // STACKEDWIDGETLIST_H
