/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef STRINGTOOLS_H
#define STRINGTOOLS_H

// Qt includes
#include <QObject>
#include <QLocale>
#include <QCollator>

// C++ includes
#include <algorithm>

class StringTools : public QObject
{
    Q_OBJECT

public:
    explicit StringTools(QObject *parent, const QString *boogerSymbol);

    template<typename T>
    void sort(T &data) const
    {
        std::sort(data.begin(), data.end(), m_collator);
    }

    QString toLower(const QString &text) const;
    QString toUpper(const QString &text) const;
    void setBoogerScore(int score);
    QString boogify(int score) const;
    QString locale() const;
    QString defaultLocale() const;
    void setLocale(const QString &name);
    bool resetLocale();
    bool localeChanged() const;
    QString dateFormat() const;
    QString timeFormat() const;

private: // Variables
    const QString *m_boogerSymbol;
    QLocale m_locale;
    QCollator m_collator;
    bool m_localeChanged = false;
    int m_boogerScore;

};

#endif // STRINGTOOLS_H
