/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "TableDelegate.h"

// Qt includes
#include <QPainter>
#include <QBrush>
#include <QDebug>
#include <QGuiApplication>

TableDelegate::TableDelegate(QObject *parent, HighlightMode highlightMode)
    : QStyledItemDelegate(parent), m_highlightMode(highlightMode)
{
    const auto palette = qGuiApp->palette();
    m_topLineColor = palette.color(QPalette::Mid);
    m_alternateBackground = QPixmap(1, 1);
    m_alternateBackground.fill(palette.color(QPalette::AlternateBase));
}

void TableDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const
{
    painter->save();

    bool drawBackground = false;
    bool drawTopLine = false;

    if ((m_highlightMode == HighlightMode::Alternating && index.row() % 2 != 0)
        || (m_highlightMode == HighlightMode::NRows && index.row() / m_highlightRows % 2 != 0)) {

        drawBackground = true;
    }

    if (m_highlightMode == HighlightMode::Custom) {
        drawBackground = index.data(Display::DrawBackground).isValid();
    }

    if (drawBackground) {
        QBrush brush = option.backgroundBrush;
        brush.setTexture(m_alternateBackground);
        painter->fillRect(option.rect, brush);
    }

    if (m_highlightMode != HighlightMode::Custom
        && index.row() != 0
        && (m_highlightMode == HighlightMode::Alternating || index.row() % m_highlightRows == 0)) {

        drawTopLine = true;
    }

    if (m_highlightMode == HighlightMode::Custom) {
        drawTopLine = index.data(Display::DrawTopLine).isValid();
    }

    if (drawTopLine) {
        painter->setPen(m_topLineColor);
        painter->drawLine(option.rect.topLeft(), option.rect.topRight());
    }

    painter->restore();

    drawText(painter, option, index);
}

void TableDelegate::drawText(QPainter *painter, const QStyleOptionViewItem &option,
                             const QModelIndex &index) const
{
    QStyledItemDelegate::paint(painter, option, index);
}

void TableDelegate::setHighlighRows(int rows)
{
    m_highlightRows = rows;
}
