/* Copyright (c) 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef TABLEDELEGATE_H
#define TABLEDELEGATE_H

// Qt includes
#include <QStyledItemDelegate>
#include <QPixmap>

// Qt classes
class QPainter;

class TableDelegate : public QStyledItemDelegate
{
    Q_OBJECT

public:
    enum HighlightMode {
        Alternating,
        NRows,
        Custom
    };

    enum Display {
        DrawBackground = Qt::UserRole,
        DrawTopLine
    };

    explicit TableDelegate(QObject *parent,
                           HighlightMode highlightMode = HighlightMode::Alternating);
    void setHighlighRows(int rows);

protected:
    virtual void paint(QPainter *painter, const QStyleOptionViewItem &option,
                       const QModelIndex &index) const override;
    virtual void drawText(QPainter *painter, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const;

private: // Variables
    HighlightMode m_highlightMode;
    QColor m_topLineColor;
    QPixmap m_alternateBackground;
    int m_highlightRows = 2;

};

#endif // TABLEDELEGATE_H
