/* Copyright (c) 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

// Local includes
#include "TitleMenu.h"

// Qt includes
#include <QWidgetAction>
#include <QLabel>
#include <QResizeEvent>
#include <QApplication>

TitleMenu::TitleMenu(QWidget *parent) : QMenu(parent)
{
    setupTitle();
}

TitleMenu::TitleMenu(const QString &text, QWidget *parent) : QMenu(text, parent)
{
    setupTitle();
    setTitle(text);
}

void TitleMenu::setupTitle()
{
    m_titleAction = new QWidgetAction(this);
    m_title = new QLabel;
    m_title->setAlignment(Qt::AlignCenter);
    m_title->setMargin(4);
    m_titleAction->setDefaultWidget(m_title);
    addAction(m_titleAction);
    addSeparator();
}

void TitleMenu::setTitle(const QString &text)
{
    m_title->setText(text);
    QResizeEvent resizeEvent(m_title->size(), size());
    QApplication::sendEvent(this, &resizeEvent);
}

QString TitleMenu::title() const
{
    return m_title->text();
}

void TitleMenu::setTitleHidden(bool state)
{
    m_titleAction->setVisible(! state);
    m_title->setVisible(! state);
}
