/* Copyright (c) 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef TOURNAMENTSETTINGS_H
#define TOURNAMENTSETTINGS_H

// Local includes
#include "Tournament.h"
#include "Markers.h"
#include "RegistrationColumns.h"
#include "Draw.h"
#include "OptionalPages.h"

// Qt includes
#include <QObject>
#include <QJsonValue>

class TournamentSettings : public QObject
{
    Q_OBJECT

public:
    explicit TournamentSettings(QObject *parent);
    int version() const;

    bool loadingDb() const;
    void setLoadingDb(bool state);

    QString updateSettingsFromV8(const QString &data) const;

    const QVector<OptionalPages::Page> &optionalPages() const;
    void setOptionalPageShown(OptionalPages::Page page, bool state);

    bool load(const QString &data);
    void setDbSettingsVersion(int version);
    int dbSettingsVersion() const;
    QString toString() const;

    void setMuckturnierVersion(const QString &muckturnierVersion);
    const QString &muckturnierVersion() const;

    void setTournamentMode(Tournament::Mode tournamentMode);
    Tournament::Mode tournamentMode() const;
    bool isPairMode() const;
    bool isSinglePlayerMode() const;

    void setTournamentOpen(bool state);
    bool tournamentOpen() const;
    bool tournamentOpenChanged() const;

    void setBoogerScore(int score);
    const int &boogerScore() const;

    void setBoogersPerRound(int count);
    int boogersPerRound() const;

    void setNoTableNumbers(bool state);
    bool noTableNumbers() const;

    void setAutoSelectPairs(bool state);
    bool autoSelectPairs() const;
    void setSelectByLastRound(bool state);
    bool selectByLastRound() const;

    void setIncludeOpponentGoals(bool state);
    bool includeOpponentGoals() const;

    void setGrayOutUnimportantGoals(bool state);
    bool grayOutUnimportantGoals() const;

    void setMarker(Markers::Type type, int id);
    int marker(Markers::Type type) const;

    void setSinglesManagement(const Markers::SinglesManagement &data);
    const Markers::SinglesManagement &singlesManagement() const;

    void setRegistrationColumns(const QVector<RegistrationColumns::Column> &data);
    const QVector<RegistrationColumns::Column> &registrationColumns() const;
    void setRegistrationListHeaderHidden(bool state);
    bool registrationListHeaderHidden() const;

    void setScoreType(Tournament::ScoreType type);
    Tournament::ScoreType scoreType() const;

    void setDrawSettings(const Draw::Settings &settings);
    const Draw::Settings &drawSettings() const;

private: // Variables
    bool m_loadingDb = false;
    QVector<OptionalPages::Page> m_optionalPages;
    QString m_muckturnierVersion;
    int m_dbSettingsVersion;
    Tournament::Mode m_tournamentMode;
    bool m_tournamentOpen;
    bool m_originalTournamentOpen;
    int m_boogerScore;
    int m_boogersPerRound;
    bool m_noTableNumbers;
    bool m_autoSelectPairs;
    bool m_selectByLastRound;
    bool m_includeOpponentGoals;
    bool m_grayOutUnimportantGoals;
    QHash<Markers::Type, int> m_marker;
    Markers::SinglesManagement m_singlesManagement;
    QVector<RegistrationColumns::Column> m_registrationColumns;
    bool m_registrationListHeaderHidden;
    Tournament::ScoreType m_scoreType;
    Draw::Settings m_drawSettings;
    QHash<QString, QJsonValue> m_unhandledValues;

};

#endif // TOURNAMENTSETTINGS_H
