/* Copyright (c) 2020 Tobias Leupold <tobias.leupold@gmx.de>

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#ifndef TOURNAMENTTEMPLATE_H
#define TOURNAMENTTEMPLATE_H

#include "Tournament.h"
#include "RegistrationColumns.h"
#include "Draw.h"
#include "DefaultValues.h"
#include "OptionalPages.h"

namespace TournamentTemplate
{

constexpr int VERSION = 3;

struct Settings
{
    Tournament::Mode tournamentMode;
    Tournament::ScoreType scoreType;
    int boogerScore;
    int boogersPerRound;
    Draw::Settings drawSettings;
    QVector<RegistrationColumns::Column> registrationColumns;
    bool registrationListHeaderHidden;
    bool autoSelectPairs;
    bool selectByLastRound;
    bool noTableNumbers;
    bool includeOpponentGoals;
    bool grayOutUnimportantGoals;
    QVector<OptionalPages::Page> optionalPages;
};

const Settings DEFAULT_SETTINGS {
    Tournament::Mode::FixedPairs,         // tournamentMode
    Tournament::ScoreType::Horizontal,    // scoreType
    DefaultValues::BOOGER_SCORE,          // boogerScore
    DefaultValues::BOOGERS_PER_ROUND,     // boogersPerRound
    Draw::DEFAULT_SETTINGS,               // drawSettings
    RegistrationColumns::DEFAULT_COLUMNS, // registrationColumns
    false,                                // registrationListHeaderHidden
    true,                                 // autoSelectPairs
    true,                                 // selectByLastRound
    false,                                // noTableNumbers
    true,                                 // includeOpponentGoals
    true,                                 // grayOutUnimportantGoals
    { }                                   // optionalPages
};

}

#endif // TOURNAMENTTEMPLATE_H
